import setuptools

import os
with open(os.path.join(os.path.dirname(os.path.abspath(__file__)), 'streamlit_marshal_helloworld/pypi_readme.md'), 'r') as f:
  long_des = f.read()

setuptools.setup(
    name="streamlit-marshal-helloworld",
    version="0.0.5",
    author="Marshal Wu",
    author_email="marshal.wu@gmail.com",
    description="使用 vite 和 vanillajs 编写的 Streamlit hello world 示例",
    long_description=long_des,
    long_description_content_type="text/markdown",
    url="https://github.com/MarshalW/streamlit-demo/tree/main/src/5.custom-components-dynamic-simple",
    keywords = ['some', 'key', 'word'],
    project_urls={
        'Source': 'https://github.com/MarshalW/streamlit-demo/tree/main/src/5.custom-components-dynamic-simple',  
    },
    packages=setuptools.find_packages(),
    include_package_data=True,
    classifiers=[],
    python_requires=">=3.10",
    install_requires=[
        # By definition, a Custom Component depends on Streamlit.
        # If your component has other Python dependencies, list
        # them here.
        "streamlit >= 1.38.0",
    ],
)


import os
import streamlit.components.v1 as components

# _RELEASE = False
_RELEASE = True

if not _RELEASE:
  _component_func = components.declare_component(
    "vite_vanilla_component",
    url="http://localhost:5173", # vite dev server port
  )
else:
  parent_dir = os.path.dirname(os.path.abspath(__file__))
  build_dir = os.path.join(parent_dir, "frontend/dist")
  _component_func = components.declare_component("vite_vanilla_component", path=build_dir)

def my_component(key=None):
  component_value = _component_func(key=key, default=0)
  return component_value

if not _RELEASE:
  import streamlit as st
  st.subheader("组件测试")
  num_clicks = my_component()
  st.markdown(f"点击了 {num_clicks} 次")